==============
eLoRA
==============

eLoRA: Efficient Rank Allocation for Budget-Constrained Fine-Tuning 🧮💰⚙️🎛️


Installation
------------

To install the package, use pip:

.. code-block:: bash

    pip install elora


Usage
-----

To use the package, import it in your Python code:

.. code-block:: python

    import elora

    rank_pattern = elora.rank_pattern(model, base_rank)


Models.

.. code-block:: python

    import elora

    # Under development


GitHub repository: https://github.com/mohsenhariri/eLoRA
